import tkinter
import math
import cmath
import tkinter.filedialog

class Farben:
    """
    erste primitive Version mit nur wenigen Farben 
    Die Farben können über die deutschen Namen oder über
    Zahlen abgerufen werden
    Hinweis:   "#fff" entspricht "weiss", 
         statt "#xxx" kann auch "red", "green"  usw. benutzt werden
    andere Lösungen mit true-colors sind denkbar
    """
    def __init__(self):
        """
        transparent, schwarz, blau, gruen, tuerkis, rot, gelb, grau, weiss
        """
        self.Fnamen = { \
                        0:"transparent", \
                        1:"schwarz" , \
                        2:"blau"    , \
                        3:"gruen"   , \
                        4:"tuerkis" , \
                        5:"rot"     , \
                        6:"gelb"    , \
                        7:"grau"    , \
                        8:"weiss"   \
                      }

        self.Farbe={ \
                      "transparent":"", \
                      "schwarz"    :"#000", \
                      "blau"       :"#00f", \
                      "gruen"      :"#0f0", \
                      "tuerkis"    :"#0ee", \
                      "rot"        :"#f00", \
                      "gelb"       :"#ff0", \
                      "grau"       :"#ccc", \
                      "weiss"      :"#fff" \
                   }

    def gibFarbeNr(self,nr):
        """
        nr : int : 0 .. 8  für die oben angegebenen Farben
        liefert die Farbdarstellung für X
        """
        return self.Farbe[self.gibFarbnamen(nr)] 

    def gibFarbnamen(self,nr):
        """
        nr : int : 0 .. 8  für die oben angegebenen Farben
        liefert den (deutschen) Bezeichner der Farbnummer (s.o.)
        """
        return self.Fnamen[nr]

    def gibFarbe(self,wort):
        """
        wort : string :  ein Element aus den oben angegebenen Farben
        liefert die Farbdarstellung fuer X
        """
        return self.Farbe[wort]

class _Leinwand:
    """
    Eine Leinwand, auf die gezeichnet werden kann. Die einzelnen Formen
    benutzen diese Leinwand, um sich darauf selbst zu zeichnen. 
    """
    _instance=None

    def __init__(self,width='18c',height='14c',bg='weiss'):
        """
        Erstellt das Fenster mit der Leinwand für das Möbelprojekt.
        width: die Breite der Leinwand; Standard: '18c' für 18cm
        height: die Höhe der Leinwand; Standard: '14c' für 14cm
        bg: die Hintergrundfarbe; Standard: 'weiss'
        """
        if _Leinwand._instance:
            raise Error("Nur eine Leinwand erlaubt!")
        else:
            _Leinwand._instance=self
            self.fenster=tkinter.Tk()
            self.farben=Farben()
            self.fenster.title('Möbelprojekt Grafik')
            self.canvas=tkinter.Canvas(self.fenster,width=width,height=height,\
                                       bg=self.farben.gibFarbe(bg))
            self.canvas.pack()

    def zeichne(self,form):
        """
        Zeichnet die Form auf die Leinwand.
        form: die zu zeichnenende Form
        """
        return form.zeichne(self)

    def loesche(self,item):
        return self.canvas.delete(item)

    def polygon(self,*coords,**kw):
        return self.canvas.create_polygon(*coords,**kw)

    def ellipse(self,x1,y1,x2,y2,**kw):
        return self.canvas.create_oval(x1,y1,x2,y2,**kw)

    def linie(self,x1,y1,x2,y2,**kw):
        return self.canvas.create_line(x1,y1,x2,y2,**kw)

    def skalieren(self,item,x,y,xFaktor,yFaktor):
        return self.canvas.scale(item,x,y,xFaktor,yFaktor)

    def bewegen(self,item,x,y):
        return self.canvas.move(item,x,y)
    
    def farbeAendern(self,item,neueFarbe):
        return self.canvas.itemconfig(item,fill=self.farben.gibFarbe(neueFarbe))

    def randfarbeAendern(self,item,neueFarbe):
        return self.canvas.itemconfig(item,outline=self.farben.gibFarbe(neueFarbe))

    def drehe(self,item,x,y,winkel):
        
        cwinkel=cmath.exp(winkel*math.pi/180*1j)
        coords=self.canvas.coords(item)
        newcoords=[]
        zentrum=complex(x,y)
        X=None
        for Y in coords:
            if X is None:
                X=Y
            else:
                neuer_punkt=cwinkel*(complex(X,Y)-zentrum)+zentrum
                newcoords.append(neuer_punkt.real)
                newcoords.append(neuer_punkt.imag)
                X=None
        self.canvas.coords(item,*newcoords)

    def bildExport(self):
        if _Leinwand._instance==None: return
        dateiname=tkinter.filedialog.asksaveasfilename(\
            parent=self.fenster,
            initialfile="Bild_.ps",
            defaultextension='ps',
            initialdir='Bilder',
            title="Bild speichern")
        if dateiname in ['',()]:
            self.Meldung('Bild nicht gespeichert','Achtung !')
        else:
            self.canvas.postscript(file=dateiname)

def Leinwand(singleton=_Leinwand()):
    """
    Liefert die Leinwand. Hiervon darf es nur ein einziges Objekt geben,
    deswegen liefert diese Funktion bei jedem Aufruf dieselbe Leinwand
    zurück. Dies ist nötig, damit die einzelnen Objekte auf dieselbe
    Leinwand gezeichnet werden anstatt eine Leinwand pro Objekt zu haben.
    """
    return singleton
