from Moebelprojekt.leinwand import Leinwand
class Stuhl:
    """
    Stellt einen Stuhl im Möbelplaner dar.
    """
    def __init__(self,xPosition=20,yPosition=20,breite=40,tiefe=45,farbe='rot'):
        """
        Erzeugt einen Stuhl an der gegebenen Position.
        xPosition: die x-Koordinate der oberen linken Ecke des Stuhls
        yPosition: die y-Koordinate der oberen linken Ecke des Stuhls
        farbe: die Farbe, in der der Stuhl angezeigt werden soll.
               Dies sollte einer der Farbnamen der Klasse Farben sein.  
        """
        self.xPosition = xPosition
        self.yPosition = yPosition
        self.breite = breite
        self.tiefe = tiefe
        self.farbe = farbe
        self.formen = []
        self.leinwand = Leinwand()

    def zeige(self):
        """
        Zeigt diesen Stuhl im Möbelplaner an.
        """
        if not self.formen:
            sitzflaeche = self.leinwand.polygon(self.xPosition,self.yPosition,\
                                                self.xPosition+self.breite,self.yPosition,\
                                                self.xPosition+self.breite+5,self.yPosition+self.tiefe,\
                                                self.xPosition-5,self.yPosition+self.tiefe)
            self.leinwand.farbeAendern(sitzflaeche,"transparent")
            self.leinwand.randfarbeAendern(sitzflaeche,"schwarz")
            self.formen.append(sitzflaeche)
            rueckenlehne = self.leinwand.linie(self.xPosition,self.yPosition+5,\
                                                 self.xPosition+self.breite,self.yPosition+5)
            self.leinwand.farbeAendern(rueckenlehne,"schwarz")
            self.formen.append(rueckenlehne)

    def verberge(self):
        """
        Entfernt diesen Stuhl aus der Ansicht im Möbelplaner.
        """
        for form in self.formen:
            self.leinwand.loesche(form)
        self.formen = []

    def drehe(self,winkel):
        """
        Dreht den Stuhl.
        winkel: der Winkel in Grad, um den im Uhrzeigersinn gedreht werden soll
        """
        for form in self.formen:
            self.leinwand.drehe(form,self.xPosition,self.yPosition,winkel)

    def horizontalBewegen(self,entfernung):
        """
        Bewegt den Stuhl in horizontaler Richtung auf der Leinwand.
        entfernung: die Anzahl an Pixeln, um die der Stuhl nach rechts
                    bewegt werden soll. Für Bewegungen nach links sind
                    negative Zahlen zu verwenden.
        """
        for form in self.formen:
            self.leinwand.bewegen(form,entfernung,0)
        self.xPosition+=entfernung
        
    def vertikalBewegen(self,entfernung):
        """
        Bewegt den Stuhl in vertikaler Richtung auf der Leinwand.
        entfernung: die Anzahl an Pixeln, um die der Stuhl nach unten
                    bewegt werden soll. Für Bewegungen nach oben sind
                    negative Zahlen zu verwenden.
        """
        for form in self.formen:
            self.leinwand.bewegen(form,0,entfernung)
        self.yPosition+=entfernung

