from Moebelprojekt.leinwand import Leinwand
class Tisch:
    """
    Stellt einen Tisch im Möbelplaner dar.
    """
    def __init__(self,xPosition=50,yPosition=50,breite=120,tiefe=60,farbe='blau'):
        """
        Erzeugt einen Tisch an der gegebenen Position.
        xPosition: die x-Koordinate der Mitte des Tischs
        yPosition: die y-Koordinate der Mitte des Tischs
        farbe: die Farbe, in der der Tisch angezeigt werden soll.
               Dies sollte einer der Farbnamen der Klasse Farben sein.  
        """
        self.xPosition = xPosition
        self.yPosition = yPosition
        self.breite = breite
        self.tiefe = tiefe
        self.farbe = farbe
        self.formen = []
        self.leinwand = Leinwand()

    def zeige(self):
        """
        Zeigt diesen Tisch im Möbelplaner an.
        """
        if not self.formen:
            tisch = self.leinwand.polygon(self.xPosition,self.yPosition,\
                                          self.xPosition+self.breite,self.yPosition,\
                                          self.xPosition+self.breite,self.yPosition+self.tiefe,\
                                          self.xPosition,self.yPosition+self.tiefe)
            self.leinwand.farbeAendern(tisch,"transparent")
            self.leinwand.randfarbeAendern(tisch,"schwarz")
            self.formen.append(tisch)


    def verberge(self):
        """
        Entfernt diesen Tisch aus der Ansicht im Möbelplaner.
        """
        for form in self.formen:
            self.leinwand.loesche(form)

    def drehe(self,winkel):
        """
        Dreht den Tisch.
        winkel: der Winkel in Grad, um den im Uhrzeigersinn gedreht werden soll
        """
        for form in self.formen:
            self.leinwand.drehe(form,self.xPosition,self.yPosition,winkel)

    def horizontalBewegen(self,entfernung):
        """
        Bewegt den Tisch in horizontaler Richtung auf der Leinwand.
        entfernung: die Anzahl an Pixeln, um die der Tisch nach rechts
                    bewegt werden soll. Für Bewegungen nach links sind
                    negative Zahlen zu verwenden.
        """
        for form in self.formen:
            self.leinwand.bewegen(form,entfernung,0)
        self.xPosition+=entfernung
        
    def vertikalBewegen(self,entfernung):
        """
        Bewegt den Tisch in vertikaler Richtung auf der Leinwand.
        entfernung: die Anzahl an Pixeln, um die der Tisch nach unten
                    bewegt werden soll. Für Bewegungen nach oben sind
                    negative Zahlen zu verwenden.
        """
        for form in self.formen:
            self.leinwand.bewegen(form,0,entfernung)
        self.yPosition+=entfernung

