from Moebelprojekt.leinwand import Leinwand
class Tisch:
    """
    Stellt einen Tisch im Möbelplaner dar.
    """
    def __init__(self,xPosition=50,yPosition=50,breite=120,tiefe=60,farbe='blau'):
        """
        Erzeugt einen Tisch an der gegebenen Position.
        xPosition: die x-Koordinate der Mitte des Tischs
        yPosition: die y-Koordinate der Mitte des Tischs
        farbe: die Farbe, in der der Tisch angezeigt werden soll.
               Dies sollte einer der Farbnamen der Klasse Farben sein.  
        """
        self.__xPosition = xPosition
        self.__yPosition = yPosition
        self.__breite = breite
        self.__tiefe = tiefe
        self.__farbe = farbe
        self.__formen = []
        self.__leinwand = Leinwand()

    def zeige(self):
        """
        Zeigt diesen Tisch im Möbelplaner an.
        """
        if not self.__formen:
            tisch = self.__leinwand.polygon(self.__xPosition,self.__yPosition,\
                                          self.__xPosition+self.__breite,self.__yPosition,\
                                          self.__xPosition+self.__breite,self.__yPosition+self.__tiefe,\
                                          self.__xPosition,self.__yPosition+self.__tiefe)
            self.__leinwand.farbeAendern(tisch,"transparent")
            self.__leinwand.randfarbeAendern(tisch,self.__farbe)
            self.__formen.append(tisch)


    def verberge(self):
        """
        Entfernt diesen Tisch aus der Ansicht im Möbelplaner.
        """
        for form in self.__formen:
            self.__leinwand.loesche(form)

    def drehe(self,winkel):
        """
        Dreht den Tisch.
        winkel: der Winkel in Grad, um den im Uhrzeigersinn gedreht werden soll
        """
        for form in self.__formen:
            self.__leinwand.drehe(form,self.xPosition,self.yPosition,winkel)

    def horizontalBewegen(self,entfernung):
        """
        Bewegt den Tisch in horizontaler Richtung auf der Leinwand.
        entfernung: die Anzahl an Pixeln, um die der Tisch nach rechts
                    bewegt werden soll. Für Bewegungen nach links sind
                    negative Zahlen zu verwenden.
        """
        for form in self.__formen:
            self.__leinwand.bewegen(form,entfernung,0)
        self.xPosition+=entfernung
        
    def vertikalBewegen(self,entfernung):
        """
        Bewegt den Tisch in vertikaler Richtung auf der Leinwand.
        entfernung: die Anzahl an Pixeln, um die der Tisch nach unten
                    bewegt werden soll. Für Bewegungen nach oben sind
                    negative Zahlen zu verwenden.
        """
        for form in self.__formen:
            self.__leinwand.bewegen(form,0,entfernung)
        self.yPosition+=entfernung

